Package: datefixR
Title: Standardize Dates in Different Formats or with Missing Data
Version: 2.0.1
Maintainer: Nathan Constantine-Cooke <nathan.constantine-cooke@ed.ac.uk>
Authors@R: c(
    person("Nathan", "Constantine-Cooke", , "nathan.constantine-cooke@ed.ac.uk", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-4437-8713")),
    person("Jonathan", "Kitt", , "jonathan.kitt@protonmail.com", role = c("ctb", "trl")),
    person("Antonio J.", "Pérez-Luque", , "ajpelu@gmail.com", role = c("ctb", "trl"),
           comment = c(ORCID = "0000-0002-1747-0469")),
    person("Daniel", "Possenriede", , "possenriede+r@gmail.com", role = c("ctb", "trl"),
           comment = c(ORCID = "0000-0002-6738-9845")),
    person("Michal", "Lauer", , "michal.lauer.25@gmail.com", role = c("ctb", "trl")),
    person("Kaique dos S.", "Alves", , "kaiquedsalves@gmail.com", role = "rev",
           comment = c(ORCID = "0000-0001-9187-0252")),
    person("Al-Ahmadgaid B.", "Asaad", , "alahmadgaid@gmail.com", role = "rev",
           comment = c(ORCID = "0000-0003-3784-8593")),
    person("Anatoly", "Tsyplenkov", , "atsyplenkov@gmail.com", role = c("ctb", "trl"),
           comment = c(ORCID = "0000-0003-4144-8402")),
    person("Chitra M.", "Saraswati", , "chitra.m.saraswati@gmail.com", role = c("ctb", "trl"),
           comment = c(ORCID = "0000-0002-8159-0414"))
  )
Description: There are many different formats dates are commonly
    represented with: the order of day, month, or year can differ,
    different separators ("-", "/", or whitespace) can be used, months can
    be numerical, names, or abbreviations and year given as two digits or
    four. 'datefixR' takes dates in all these different formats and
    converts them to R's built-in date class. If 'datefixR' cannot
    standardize a date, such as because it is too malformed, then the user
    is told which date cannot be standardized and the corresponding ID for
    the row. 'datefixR' also allows the imputation of missing days and
    months with user-controlled behavior.
License: GPL (>= 3)
URL: https://docs.ropensci.org/datefixR/,
        https://github.com/ropensci/datefixR
BugReports: https://github.com/ropensci/datefixR/issues
Depends: R (>= 4.2)
Imports: lifecycle, rlang
Suggests: anytime, DT, future, future.apply, htmltools, knitr,
        parsedate, pkgbuild, png, readr, readxl, rmarkdown, shiny,
        shinytest2, spelling, testthat (>= 3.0.0), withr
VignetteBuilder: knitr
Config/testthat/edition: 3
Config/testthat/parallel: true
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.3
Config/rextendr/version: 0.5.0
SystemRequirements: Cargo (Rust's package manager), rustc, xz
NeedsCompilation: yes
Packaged: 2026-04-27 13:44:59 UTC; nconsta2
Author: Nathan Constantine-Cooke [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4437-8713>),
  Jonathan Kitt [ctb, trl],
  Antonio J. Pérez-Luque [ctb, trl] (ORCID:
    <https://orcid.org/0000-0002-1747-0469>),
  Daniel Possenriede [ctb, trl] (ORCID:
    <https://orcid.org/0000-0002-6738-9845>),
  Michal Lauer [ctb, trl],
  Kaique dos S. Alves [rev] (ORCID:
    <https://orcid.org/0000-0001-9187-0252>),
  Al-Ahmadgaid B. Asaad [rev] (ORCID:
    <https://orcid.org/0000-0003-3784-8593>),
  Anatoly Tsyplenkov [ctb, trl] (ORCID:
    <https://orcid.org/0000-0003-4144-8402>),
  Chitra M. Saraswati [ctb, trl] (ORCID:
    <https://orcid.org/0000-0002-8159-0414>)
Repository: CRAN
Date/Publication: 2026-04-27 14:00:09 UTC
Built: R 4.5.2; x86_64-apple-darwin20; 2026-05-01 17:29:58 UTC; unix
Archs: datefixR.so.dSYM
