# Generated by roxygen2: do not edit by hand

export(fix_date)
export(fix_date_app)
export(fix_date_char)
export(fix_date_df)
export(fix_dates)
importFrom(Rcpp,sourceCpp)
importFrom(lifecycle,deprecated)
useDynLib(datefixR, .registration = TRUE)
