# Generated by extendr: Do not edit by hand

# nolint start

#
# This file was created with the following call:
#   .Call("wrap__make_datefixR_wrappers", use_symbols = TRUE, package_name = "datefixR")

#' @usage NULL
#' @useDynLib datefixR, .registration = TRUE
NULL

#' Validate day imputation value range
#' @noRd
checkday <- function(day_impute) .Call(wrap__checkday, day_impute)

#' Main date fixing function - Rust implementation of .fix_date
#' @noRd
fix_date <- function(date, day_impute, month_impute, subject, format, excel, roman_numeral) .Call(wrap__fix_date, date, day_impute, month_impute, subject, format, excel, roman_numeral)

#' Analyze and fix date strings in a whole column of a DataFrame
#' @noRd
fix_date_column <- function(dates, day_impute, month_impute, subjects, format, excel, roman_numeral) .Call(wrap__fix_date_column, dates, day_impute, month_impute, subjects, format, excel, roman_numeral)


# nolint end
