#' Example dataset of dates in different formats
#'
#' A toy dataset to use with datefixR functions.
#'
#' @format A data frame with 5 rows and 3 variables:
#' \describe{
#'   \item{id}{Row ID (numeric).}
#'   \item{some.dates}{Dates in different formats (character).}
#'   \item{some.more.dates}{Additional dates in different formats (character).}
#' }
"exampledates"
